gchecky.model.buyer_marketing_preferences_t

Package gchecky :: Module model :: Class buyer_marketing_preferences_t |
[hide private]
[frames] | no frames]

# Class buyer_marketing_preferences_t

source code

    object --+
             |
     gxml.Node --+
                 |
                buyer_marketing_preferences_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
read(self, node) Load a Node from an xml DOM node. | source code
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| email_allowed = `gxml.Boolean('email-allowed')`
| _fields = ``{``'``email_allowed``'``:` `??``}`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### read(self, node) | source code
Load a Node from an xml DOM node. Overrides: gxml.Node.read (inherited documentation)